# neompy

## Description

Sinek Development tools for internal projects with strong web development coupling.

## Modules

* _core_: runtime to improve development a testing
* _ddd_: domain modeling tools
* _management_: development tools

## Contributors

* @Fabwert
* @jose-mrqz
